# MultiCloudAccountInfo


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**account_credentials** | **str** |  | [optional] 
**account_id** | **str** |  | [optional] 
**account_name** | **str** |  | [optional] 
**aws_cloud_gateway_with_tvpc_enabled** | **bool** |  | [optional] 
**aws_iam_credentials** | [**AwsIamCredentials**](AwsIamCredentials.md) |  | [optional] 
**aws_key_credentials** | [**AwsKeyCredentials**](AwsKeyCredentials.md) |  | [optional] 
**az_o365_enabled** | **bool** |  | [optional] 
**azure_credentials** | [**AzureCredentials**](AzureCredentials.md) |  | [optional] 
**client_email** | **str** |  | [optional] 
**cloud_gateway_enabled** | **bool** |  | [optional] 
**cloud_type** | **str** |  | [optional] 
**cred_type** | **str** |  | [optional] 
**description** | **str** |  | [optional] 
**gcp_billing_id** | **str** |  | [optional] 
**gcp_credentials** | [**GcpCredentials**](GcpCredentials.md) |  | [optional] 
**host_vpc_enabled** | **bool** |  | [optional] 
**org_name** | **str** |  | [optional] 
**private_key_id** | **str** |  | [optional] 
**region_list** | **[str]** |  | [optional] 
**service_discovery_enabled** | **bool** |  | [optional] 
**vnet_enabled** | **bool** |  | [optional] 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


